#!/bin/sh
# $Id$

usage()
{
	echo "usage: dep.sh x86|x64"
	exit 1
}

set -e
set -o pipefail

if [[ $# != 1 ]]; then
	usage
fi


TARGET=$HOME/dev/libraries
TEMP_TARGET_NAME=temp
TEMP_TARGET=$TARGET/$TEMP_TARGET_NAME
PWD=`pwd`
CPU_COUNT=4
#`grep -c "^processor" /proc/cpuinfo`
CONFIGURE="./configure -q"
MAKE="make -j $CPU_COUNT -s"
B2="./b2 -d0 -j $CPU_COUNT -q"
BJAM="$TARGET/boost_1_52_0/bjam -d0 -j $CPU_COUNT -q"

if [ $1 = "x86" ]; then
	ARCH=x86
	ADDRESS_MODEL=32
elif [ $1 = "x64" ]; then
	ARCH=x64
	ADDRESS_MODEL=64
else
	usage
fi
	
FETCH="curl -L -O -#"
UNARCHIVE="tar"
# --force-local

PLATFORM=`uname`
WXWIDGETS_CONFIGURE_FLAGS="--enable-monolithic --enable-debug --enable-debug_info --enable-debug_gdb --disable-compat29"

if [ $PLATFORM = "Darwin" ]; then
	WXWIDGETS_CONFIGURE_FLAGS="$WXWIDGETS_CONFIGURE_FLAGS --with-cocoa"
fi


mkdir -p "$TARGET"
mkdir -p "$TEMP_TARGET"

download()
{
	echo downloading
	
	cd "$TEMP_TARGET"

	echo wxwidgets
	$FETCH "http://downloads.sourceforge.net/project/wxwindows/2.9.4/wxWidgets-2.9.4.tar.bz2"

	echo python
	$FETCH "http://www.python.org/ftp/python/3.3.0/Python-3.3.0.tar.bz2"

	echo boost
	$FETCH "https://downloads.sourceforge.net/project/boost/boost/1.52.0/boost_1_52_0.tar.bz2?r=&ts=1356557543&use_mirror=hivelocity"

	echo libtorrent
	$FETCH "https://libtorrent.googlecode.com/files/libtorrent-rasterbar-0.16.6.tar.gz"

	echo libxml2
	$FETCH "ftp://xmlsoft.org/libxml2/libxml2-2.8.0.tar.gz"

	echo curl
	$FETCH "http://curl.haxx.se/download/curl-7.27.0.tar.bz2"

	echo libiconv
	$FETCH "http://ftp.gnu.org/pub/gnu/libiconv/libiconv-1.14.tar.gz"

	cd -
}

untar()
{
	echo untaring
	cd $TARGET

	set +e
	FILES=`find $TEMP_TARGET_NAME/*`
	if [[ $? -ne 0 ]]; then
   		echo $FILES | xargs -n1 $UNARCHIVE -xf
		rm -R $TEMP_TARGET
	fi
	set -e
}

build_wxwidgets()
{
	echo "building wxWidgets"
	cd $TARGET/wxWidgets*
	$CONFIGURE $WXWIDGETS_CONFIGURE_FLAGS
	$MAKE
	mv lib lib.$ARCH.debug
}

build_python()
{
	echo building python
	cd $TARGET/Python*
	$CONFIGURE CFLAGS=-fPIC CPPFLAGS=-fPIC
	$MAKE
	cp pyconfig.h Include/
	cd Lib
	zip -r python33.zip *
}

build_boost()
{
	echo building boost
	cd $TARGET/boost*
	./bootstrap.sh
	sed 's/using python/# using python/' project-config.jam > project-config.jam.temp
	rm project-config.jam
	mv project-config.jam.temp project-config.jam
	echo "using python : 3.3 : $TARGET/Python-3.3.0/python : $TARGET/Python-3.3.0/Include/ : $TARGET/Python-3-3.0 ;" >> project-config.jam
	$B2 variant=debug link=static runtime-link=shared threading=multi debug-symbols=on address-model=$ADDRESS_MODEL cxxflags=-fPIC --with-chrono --with-date_time --with-exception --with-filesystem --with-program_options --with-regex --with-signals --with-system --with-thread --with-test --with-python stage
	mv stage/lib stage/lib.$ARCH.debug
}

build_libtorrent()
{
	echo building libtorrent
	cd $TARGET/libtorrent*
	export BOOST_BUILD_PATH=$TARGET/boost_1_52_0/tools/build/v2/
	export BOOST_ROOT=$TARGET/boost_1_52_0/
	$BJAM toolset=gcc boost=source boost-link=static link=static runtime-link=shared variant=debug debug-symbols=on address-model=$ADDRESS_MODEL cxxflags=-fPIC logging=none asserts=off geoip=off encryption=openssl invariant-checks=on resolve-countries=off deprecated-functions=off full-stats=off
	mkdir -p lib.$ARCH.debug
	find bin -name "*.a" -exec cp '{}' ./lib.$ARCH.debug \;
}

build_libxml()
{
	echo building libxml
	cd $TARGET/libxml*
	$CONFIGURE --enable-silent-rules CPPFLAGS=-fPIC CFLAGS=-fPIC
	$MAKE
}

build_curl()
{
	echo building curl
	cd $TARGET/curl*
	$CONFIGURE --disable-shared --disable-ldap --enable-debug --enable-curldebug --without-librtmp
	$MAKE
}

build_iconv()
{
	echo building iconv
	cd $TARGET/libiconv*
	$CONFIGURE --enable-static CPPFLAGS=-fPIC CFLAGS=-fPIC
	$MAKE
}

#download
#untar
build_wxwidgets
#build_python
#build_boost
#build_libtorrent
#build_libxml
#build_curl
#build_iconv

echo done

